@@ -109,7 +109,22 @@ def _format_detailed_error(message, details):
 
 
 class NotMasterError(AutoReconnect):
-    """The server responded "not master" or "node is recovering".
+    """**DEPRECATED** - The server responded "not master" or
+    "node is recovering".
+
+    This exception has been deprecated and will be removed in PyMongo 4.0.
+    Use :exc:`~pymongo.errors.NotPrimaryError` instead.
+
+    .. versionchanged:: 3.12
+      Deprecated. Use :exc:`~pymongo.errors.NotPrimaryError` instead.
+    """
+    def __init__(self, message='', errors=None):
+        super(NotMasterError, self).__init__(
+            _format_detailed_error(message, errors), errors=errors)
+
+
+class NotPrimaryError(NotMasterError):
+    """The server responded "not primary" or "node is recovering".
 
     These errors result from a query, write, or command. The operation failed
     because the client thought it was using the primary but the primary has
@@ -120,10 +135,11 @@ class NotMasterError(AutoReconnect):
     its view of the server as soon as possible after throwing this exception.
 
     Subclass of :exc:`~pymongo.errors.AutoReconnect`.
+
+    .. versionadded:: 3.12
     """
     def __init__(self, message='', errors=None):
-        super(NotMasterError, self).__init__(
-            _format_detailed_error(message, errors), errors=errors)
+        super(NotPrimaryError, self).__init__(message, errors=errors)
 
 
 class ServerSelectionTimeoutError(AutoReconnect):
